@@ -1,3 +1,3 @@
 from .scorer import Scorer
-from .constants import Constants, Errors
+from .constants import Errors
 from .config import Config
